..
  This file describes user-visible changes between the versions.

# Change History

## Development

### 0.0.1

2022-07-26

- Package renamed as `murky` (formerly `condatools`, `boiga`, and `water_moccasin`).
